# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import horizon


class CuteGroup(horizon.PanelGroup):
    slug = "cute"
    name = "Cute Cats"
    panels = ('kittens',)


class FierceGroup(horizon.PanelGroup):
    slug = "fierce"
    name = "Fierce Cats"
    panels = ("tigers",)


class Cats(horizon.Dashboard):
    name = "Cats"
    slug = "cats"
    panels = (CuteGroup, FierceGroup)
    default_panel = 'kittens'


horizon.register(Cats)
